==> call-uikit-vue-2.3.3.tgz: package/src/TUICallService/locales/en.ts <==
export const en = {
  'hangup': 'Hang up',
  'reject': 'Decline',
  'other side reject call': 'other side reject call',
  'reject call': 'Reject Call',
  'accept': 'Accept',
  'cancel': 'Cancel Call',
  'other side line busy': 'other side line busy',
  'in busy': 'in busy',
  'call timeout': 'call timeout',
  'no response from the other side': 'no response from the other side',
  'end call': 'end call',
  'timeout': 'timeout',
  'kick out': 'kick out',
  'caller calling message': 'Waiting for the callee to accept the invitation...',
  'callee calling video message': 'You are invited to a video call...',
  'callee calling audio message': 'You are invited to a audio call...',
  'no microphone access': 'no microphone access',
  'no camera access': 'no camera access',

  'speaker':'speaker',
  'Invited group call':'Invited you to a group call',
  'Those involved':'Those involved in the call are',
  'call': 'call',
  'video-call': 'video call',
  'audio-call': 'audio call',
  'search': 'search',
  'search-result': 'search result',
  'no-user': 'user not found',
  'member-not-added': 'member not added',
  'input-phone-userID': 'phone number or userID',
  'not-login': 'not logged in',
  'login-status-expire': 'login status is invalid, please refresh the page and try again',
  'experience-multi-call': 'experience multi-person calls, please download the full-featured demo: ',
  'not-support-multi-call': 'multi-person call interface is not open',
  'userID': 'userID',
  'already-enter': 'entered the call',
  'waiting': 'Calling...',
  'camera-opened': 'Camera on',
  'camera-closed': 'Camera off',
  'microphone-opened': 'Mic on',
  'microphone-closed': 'Mic off',
  'camera': 'Camera',
  'microphone': 'Microphone',
  'image-resolution': 'Resolution',
  'default-image-resolution': 'Default',
  'invited-person': 'Invite',
  'video-to-audio': 'Switch to audio',
  'me': '(me)',
  'start-voice-call': 'Audio call from ',
  'start-video-call': 'Video call from ',
  'be-rejected': 'Call declined, ',
  'be-no-response': 'No response, ',
  'be-line-busy': 'Line busy, ',
  'be-canceled': 'The call is canceled, ',
  'voice-call-end': 'Voice call ended',
  'video-call-end': 'Video call ended',
  'method-call-failed': 'Failed to sync the operation',
  'failed-to-obtain-permission': 'Failed to obtain permissions',
  'environment-detection-failed': 'Failed to check the environment',
  'call-failed': 'call method failed',
  'microphone-unavailable': 'No mic found',
  'ban-device': 'Device access denied',
  'not-supported-webrtc': 'Your current environment does not support WebRTC',
  'is-already-calling': 'TUICallKit is already on a call',
  'need-init': 'Before initiating a call with TUICallKit, ensure that the TUICallKitServer.init() method has executed successfully. ',
  "can't call yourself": "Can't call yourself",
  'Use-phone-and-computer': 'Use your mobile phone and computer to experience video calls',
  'Wechat scan right QR code': 'Wechat scan right QR code',
  'try': 'try',
  'Scan the QR code above': 'Scan the QR code above',
  'Make video calls yourself': 'Make video calls yourself',
  'accept-error': 'Accept failed',
  'accept-device-error': 'Accept failed, unable to auth calling device',
  'call-error': 'Start call failed',
};

==> call-uikit-vue-2.3.8.tgz: package/src/TUICallService/locales/en.ts <==
export const en = {
  'hangup': 'Hang up',
  'reject': 'Decline',
  'other side reject call': 'other side reject call',
  'reject call': 'Reject Call',
  'accept': 'Accept',
  'cancel': 'Cancel Call',
  'other side line busy': 'other side line busy',
  'in busy': 'in busy',
  'call timeout': 'call timeout',
  'no response from the other side': 'no response from the other side',
  'end call': 'end call',
  'timeout': 'timeout',
  'kick out': 'kick out',
  'caller calling message': 'Waiting for the callee to accept the invitation...',
  'callee calling video message': 'You are invited to a video call...',
  'callee calling audio message': 'You are invited to a audio call...',
  'no microphone access': 'no microphone access',
  'no camera access': 'no camera access',

  'speaker': 'speaker',
  'Invited group call': 'Invited you to a group call',
  'Those involved': 'Those involved in the call are',
  'call': 'call',
  'video-call': 'video call',
  'audio-call': 'audio call',
  'search': 'search',
  'search-result': 'search result',
  'no-user': 'user not found',
  'member-not-added': 'member not added',
  'input-phone-userID': 'phone number or userID',
  'not-login': 'not logged in',
  'login-status-expire': 'login status is invalid, please refresh the page and try again',
  'experience-multi-call': 'experience multi-person calls, please download the full-featured demo: ',
  'not-support-multi-call': 'multi-person call interface is not open',
  'userID': 'userID',
  'already-enter': 'entered the call',
  'waiting': 'Calling...',
  'camera-opened': 'Camera on',
  'camera-closed': 'Camera off',
  'microphone-opened': 'Mic on',
  'microphone-closed': 'Mic off',
  'camera': 'Camera',
  'microphone': 'Microphone',
  'image-resolution': 'Resolution',
  'default-image-resolution': 'Default',
  'invited-person': 'Invite',
  'video-to-audio': 'Switch to audio',
  'me': '(me)',
  'start-voice-call': 'Audio call from ',
  'start-video-call': 'Video call from ',
  'be-rejected': 'Call declined, ',
  'be-no-response': 'No response, ',
  'be-line-busy': 'Line busy, ',
  'be-canceled': 'The call is canceled, ',
  'voice-call-end': 'Voice call ended',
  'video-call-end': 'Video call ended',
  'method-call-failed': 'Failed to sync the operation',
  'failed-to-obtain-permission': 'Failed to obtain permissions',
  'environment-detection-failed': 'Failed to check the environment',
  'switchToAudioCall-call-failed': 'switch to audio call method failed',
  'switchToVideoCall-call-failed': 'switch to video call method failed',
  'microphone-unavailable': 'No mic found',
  'camera-unavailable': 'No camera found',
  'ban-device': 'Device access denied',
  'not-supported-webrtc': 'Your current environment does not support WebRTC',
  'is-already-calling': 'TUICallKit is already on a call',
  'need-init': 'Before initiating a call with TUICallKit, ensure that the TUICallKitServer.init() method has executed successfully. ',
  "can't call yourself": "Can't call yourself", // eslint-disable-line
  'Use-phone-and-computer': 'Use your mobile phone and computer to experience video calls',
  'Wechat scan right QR code': 'Wechat scan right QR code',
  'try': 'try',
  'Scan the QR code above': 'Scan the QR code above',
  'Make video calls yourself': 'Make video calls yourself',
  'accept-error': 'Accept failed',
  'accept-device-error': 'Accept failed, unable to auth calling device',
  'call-error': 'Start call failed',
  'browser-authorization': 'Browser authorization',
  'mac-privacy': 'System Preferences -> Security and Privacy -> Privacy',
  'win-privacy': 'Setting -> Privacy and Security -> App permissions',
  'mac-preferences': 'Open System Preferences',
  'win-preferences': 'Open Setting',
};
